@@ -55,7 +55,6 @@ class Command:
     def absolutePosition(self, value):
         cmd: str = 'A'
         cmd += str(value)
-        print("ajung aici?")
         return cmd
 
     def relativePickup(self, value: int):
@@ -82,7 +81,7 @@ class Command:
         Valve Commands
     '''
 
-    def vMoveValveToInputPosition(self, value=0):
+    def moveValveToInputPosition(self, value=0):
         cmd: str = 'I'
         if value == 0:
             print("Default command!")
@@ -93,7 +92,7 @@ class Command:
             print("Wrong parameter value for Move valve to input position command!")
         return cmd
 
-    def vMoveValveToOutputPosition(self, value=0):
+    def moveValveToOutputPosition(self, value=0):
         cmd: str = 'O'
         if value == 0:
             print("Default command!")
@@ -104,17 +103,17 @@ class Command:
             print("Wrong parameter value for Move valve to output position command!")
         return cmd
 
-    def vMoveValveToBypass(self):
+    def moveValveToBypass(self):
         return 'B'
 
-    def vMoveValveToExtraPosition(self):
+    def moveValveToExtraPosition(self):
         return 'E'
 
     """
         Action commands
     """
 
-    def aDefinePositionInCommandString(self):
+    def definePositionInCommandString(self):
         cmd: str = 'g'
         self.command_g_counter += 1
         print("actual value of g command: " + str(self.command_g_counter))
@@ -125,7 +124,7 @@ class Command:
         return cmd
 
     # Gx - Repeat Commands
-    def aRepeatCommands(self, value=0):
+    def repeatCommands(self, value=0):
         cmd: str = 'G'
         self.command_G_counter += 1
         if value == 0:
@@ -145,7 +144,7 @@ class Command:
         return cmd
 
     # Mx - Delay - performs a delay of x milliseconds.where 5 ≤ x ≤ 30,000 milliseconds.
-    def aDelay(self, value: int):
+    def delay(self, value: int):
         cmd: str = 'M'
         if 5 <= value <= 30000:
             cmd += str(value)
@@ -155,7 +154,7 @@ class Command:
         return cmd
 
     # Hx - Halt Command Execution
-    def aHalt(self, value: int):
+    def halt(self, value: int):
         cmd: str = 'H'
         if 0 <= value <= 2:
             cmd += str(value)
@@ -165,7 +164,7 @@ class Command:
         return cmd
 
     # Jx - Auxiliary Outputs
-    def aAuxiliaryOutputs(self, value: int):
+    def auxiliaryOutputs(self, value: int):
         cmd: str = 'J'
         if 0 <= value <= 7:
             cmd += str(value)
@@ -175,7 +174,7 @@ class Command:
         return cmd
 
     # sx - Store Command String
-    def aStoreCommandString(self, location: int, command: str):
+    def storeCommandString(self, location: int, command: str):
         cmd: str = 's'
         if 0 <= location <= 14:
             cmd += str(location)
@@ -186,7 +185,7 @@ class Command:
         return cmd
 
     # ex - Execute Command String in EEPROM Location
-    def aExecuteCommandStringInEEPROMLocation(self, location: int):
+    def executeCommandStringInEEPROMLocation(self, location: int):
         cmd: str = 'e'
         if 0 <= location <= 14:
             cmd += str(location)
@@ -195,14 +194,14 @@ class Command:
             print("Wrong parameter value for Execute Command String in EEPROM Location command!")
         return cmd
 
-    def aTerminateCommandBuffer(self):
+    def terminateCommandBuffer(self):
         return 'T'
 
     """
         Motor Commands
     """
 
-    def mSetAcceleration(self, value: int):
+    def setAcceleration(self, value: int):
         cmd: str = 'L'
         if 0 <= value <= 20:
             cmd += str(value)
@@ -211,7 +210,7 @@ class Command:
             print("Wrong parameter value for set acceleration command!")
         return cmd
 
-    def mSetSpeed(self, value: int):
+    def setSpeed(self, value: int):
         cmd: str = 'S'
         if 1 <= value <= 40:
             cmd += str(value)
@@ -220,7 +219,7 @@ class Command:
             print("Wrong parameter value for set speed command!")
         return cmd
 
-    def mIncreaseStopVelocityBySteps(self, value: int):
+    def increaseStopVelocityBySteps(self, value: int):
         cmd: str = 'C'
         if 0 <= value <= 25:
             cmd += str(value)
@@ -229,7 +228,7 @@ class Command:
             print("Wrong parameter value for Increase Stop Velocity by Steps command!")
         return cmd
 
-    def mSetStartVelocity(self, value: int):
+    def setStartVelocity(self, value: int):
         cmd: str = 'v'
         if 50 <= value <= 1000:
             cmd += str(value)
@@ -238,7 +237,7 @@ class Command:
             print("Wrong parameter value for set start velocity command!")
         return cmd
 
-    def mSetMaximumVelocity(self, value: int):
+    def setMaximumVelocity(self, value: int):
         cmd: str = 'V'
         if 2 <= value <= 5800:
             cmd += str(value)
@@ -247,7 +246,7 @@ class Command:
             print("Wrong parameter value for set maximum velocity command!")
         return cmd
 
-    def mStopVelocity(self, value: int):
+    def stopVelocity(self, value: int):
         cmd: str = 'c'
         if 50 <= value <= 2700:
             cmd += str(value)
@@ -261,18 +260,18 @@ class Command:
         h30000 - Disable h Factor Commands and Queries
     """
 
-    def hEnableFactorCommands(self, bValue: bool):
+    def enableFactorCommands(self, bValue: bool):
         cmd: str = 'h3000'
         cmd += str(int(bValue))
         return cmd
 
-    def hResetPSD(self):
+    def resetPSD(self):
         return "h30003"
 
-    def hInitializeValve(self):
+    def initializeValve(self):
         return "h20000"
 
-    def hInitializeSyringeOnly(self, speedCode: int):
+    def initializeSyringeOnly(self, speedCode: int):
         cmd: str = 'h'
         cmdValue = 10000
         # permitted values between 0-40
@@ -281,7 +280,7 @@ class Command:
         cmd += str(cmdValue)
         return cmd
 
-    def hSetSyringeMode(self, mode: int):
+    def setSyringeMode(self, mode: int):
         cmd: str = 'h'
         cmdValue = 11000
         # permitted values between 0-15
@@ -292,7 +291,7 @@ class Command:
         print(cmd)
         return cmd
 
-    def hEnableValveMovement(self, bValue: bool):
+    def enableValveMovement(self, bValue: bool):
         cmd: str = 'h2000'
         if bValue is True:
             cmd += '1'
@@ -300,33 +299,33 @@ class Command:
             cmd += '2'
         return cmd
 
-    def hSetValveType(self, type: int):
+    def setValveType(self, type: int):
         cmd: str = 'h2100'
         # permitted values between 0-6
         if 0 <= type <= 6:
             cmd += str(type)
         return cmd
 
-    def hMoveValveToSpecificPositionInShortestDirection(self, specificPosition: PositionInShortestDirection):
+    def moveValveToSpecificPositionInShortestDirection(self, specificPosition: PositionInShortestDirection):
         cmd: str = 'h2300'
         cmd += str(specificPosition.value)
         return cmd
 
-    def hMoveValveClockwiseDirection(self, position: int):
+    def moveValveClockwiseDirection(self, position: int):
         cmd: str = 'h2400'
         # permitted values between 1-8
         if 1 <= position <= 8:
             cmd += str(position)
         return cmd
 
-    def hMoveValveCounterclockwiseDirection(self, position: int):
+    def moveValveCounterclockwiseDirection(self, position: int):
         cmd: str = 'h2500'
         # permitted values between 1-8
         if 1 <= position <= 8:
             cmd += str(position)
         return cmd
 
-    def hMoveValveInShortestDirection(self, position: int):
+    def moveValveInShortestDirection(self, position: int):
         cmd: str = 'h2600'
         # permitted values between 1-8
         if 1 <= position <= 8:
@@ -341,13 +340,13 @@ class Command:
         cmd += str(cmdValue)
         return cmd
 
-    def hClockwiseAngularValveMove(self, position: int):
+    def clockwiseAngularValveMove(self, position: int):
         return self.valveMovementHelper(27000, position)
 
-    def hCounterclockwiseAngularValveMove(self, position: int):
+    def counterclockwiseAngularValveMove(self, position: int):
         return self.valveMovementHelper(28000, position)
 
-    def hShortestDirectAngularValveMove(self, position: int):
+    def shortestDirectAngularValveMove(self, position: int):
         return self.valveMovementHelper(29000, position)
 
     """
